@@ -7,34 +7,15 @@ import (
 )
 
 func TestGoldenAddCmd(t *testing.T) {
-
-	wd, _ := os.Getwd()
 	command := &Command{
 		CmdName:   "test",
 		CmdParent: parentName,
-		Project: &Project{
-			AbsolutePath: fmt.Sprintf("%s/testproject", wd),
-			Legal:        getLicense(),
-			Copyright:    copyrightLine(),
-
-			// required to init
-			AppName: "testproject",
-			PkgName: "github.com/spf13/testproject",
-			Viper:   true,
-		},
+		Project:   getProject(),
 	}
+	defer os.RemoveAll(command.AbsolutePath)
 
-	// init project first
-	command.Project.Create()
-	defer func() {
-		if _, err := os.Stat(command.AbsolutePath); err == nil {
-			os.RemoveAll(command.AbsolutePath)
-		}
-	}()
-
-	if err := command.Create(); err != nil {
-		t.Fatal(err)
-	}
+	assertNoErr(t, command.Project.Create())
+	assertNoErr(t, command.Create())
 
 	generatedFile := fmt.Sprintf("%s/cmd/%s.go", command.AbsolutePath, command.CmdName)
 	goldenFile := fmt.Sprintf("testdata/%s.go.golden", command.CmdName)
